@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002-2006  Mattia Dongili <malattia@linux.it>
+ *  Copyright (C) 2002-2008  Mattia Dongili <malattia@linux.it>
  *                           George Staikos <staikos@0wned.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -23,21 +23,33 @@
 #include <stdlib.h>
 #include <string.h>
 #include "cpufreqd_plugin.h"
+#include "cpufreqd_acpi.h"
 #include "cpufreqd_acpi_ac.h"
 
-#define ACPI_AC_DIR "/proc/acpi/ac_adapter/"
-#define ACPI_AC_FILE "/state"
-#define ACPI_AC_FORMAT "state:                   %s\n"
+#define POWER_SUPPLY "power_supply"
+#define AC_TYPE "Mains"
+#define AC_ONLINE "online"
 
 #define PLUGGED   1
 #define UNPLUGGED 0
 
-static char *ac_filelist[64];
+static struct sysfs_attribute *mains[64];
 static unsigned short ac_state;
 static int ac_dir_num;
 
-static int no_dots(const struct dirent *d) {
-	return d->d_name[0]!= '.';
+static int mains_callback(struct sysfs_class_device *cdev) {
+	struct sysfs_attribute *attr = get_class_device_attribute(cdev,
+			AC_ONLINE);
+	if (attr) {
+		/* success */
+		mains[ac_dir_num] = attr;
+		ac_dir_num++;
+	}
+	/* we don't care about the class_device
+	 * returning 1 will force find_class_device
+	 * to close it
+	 */
+	return 1;
 }
 
 /*  static int acpi_ac_init(void)
@@ -45,36 +57,18 @@ static int no_dots(const struct dirent *d) {
  *  test if AC dirs are present
  */
 int acpi_ac_init(void) {
-	struct dirent **namelist = NULL;
-	int n = 0;
 
-	/* get AC path */
-	n = scandir(ACPI_AC_DIR, &namelist, no_dots, NULL);
-	if (n > 0) {
-		ac_dir_num = n;
-		*ac_filelist = malloc(n * 64 * sizeof(char));
-		while (n--) {
-			snprintf(ac_filelist[n], 64, "%s%s%s", ACPI_AC_DIR, namelist[n]->d_name, ACPI_AC_FILE);
-			clog(LOG_INFO, "AC path %s\n", ac_filelist[n]);
-			free(namelist[n]);
-		} 
-		free(namelist);
-
-	} else if (n < 0) {
-		clog(LOG_DEBUG, "no acpi_ac module compiled or inserted? (%s: %s)\n",
-				ACPI_AC_DIR, strerror(errno));
-		return -1;
-
-	} else {
-		clog(LOG_NOTICE, "no ac adapters found, not a laptop?\n");
+	find_class_device(POWER_SUPPLY, AC_TYPE, mains_callback);
+	if (ac_dir_num <= 0) {
+		clog(LOG_INFO, "No AC adapters found\n");
 		return -1;
 	}
 	return 0;
 }
 
 int acpi_ac_exit(void) {
-	if (ac_filelist != NULL)
-		free(*ac_filelist);
+	while (--ac_dir_num >= 0)
+		put_attribute(mains[ac_dir_num]);
 	clog(LOG_INFO, "exited.\n");
 	return 0;
 }
@@ -84,23 +78,18 @@ int acpi_ac_exit(void) {
  *  reads temperature valuse ant compute a medium value
  */
 int acpi_ac_update(void) {
-	char temp[50];
-	int i=0;
-	FILE *fp = NULL;
+	int value;
+	int i = 0;
 
 	ac_state = UNPLUGGED;
 	clog(LOG_DEBUG, "called\n");
-	for (i=0; i<ac_dir_num; i++) {
-		fp = fopen(ac_filelist[i], "r");
-		if (!fp) {
-			clog(LOG_ERR, "%s: %s\n", ac_filelist[i], strerror(errno));
-			return -1;
-		}
-		fscanf(fp, ACPI_AC_FORMAT, temp);
-		fclose(fp);
+	for (i = 0; i < ac_dir_num; i++) {
+		/* check power_supply type */
+		if (read_int(mains[i], &value))
+				continue;
 
-		clog(LOG_DEBUG, "read %s\n", temp);
-		ac_state |= (strncmp(temp, "on-line", 7)==0 ? PLUGGED : UNPLUGGED);
+		clog(LOG_DEBUG, "read %s:%d\n", mains[i]->path, value);
+		ac_state |= value ? PLUGGED : UNPLUGGED;
 	}
 
 	clog(LOG_INFO, "ac_adapter is %s\n",
