@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2002-2006  Mattia Dongili <malattia@linux.it>
+ *  Copyright (C) 2002-2008  Mattia Dongili <malattia@linux.it>
  *                           George Staikos <staikos@0wned.org>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -147,7 +147,7 @@ static unsigned int rule_score(struct rule *rule) {
 	} /* end foreach rule entry */
 	if (directives > 0)
 		return hits + (100 * hits / directives);
-	clog(LOG_INFO, "No evaulatable directives in Rule \"%s\".\n", rule->name);
+	clog(LOG_INFO, "No evaluatable directives in Rule \"%s\".\n", rule->name);
 	return 0;
 }
 
@@ -293,12 +293,12 @@ static int set_cpufreqd_runmode(int mode) {
 static int read_args (int argc, char *argv[]) {
 
 	static struct option long_options[] = {
-		{ "help", 0, 0, 'h' }, 
-		{ "version", 0, 0, 'v' }, 
-		{ "file", 1, 0, 'f' },
-		{ "no-daemon", 0, 0, 'D' },
-		{ "manual", 0, 0, 'm' },
-		{ "verbosity", 1, 0, 'V' },
+		{ "help",	0, 0, 'h' }, 
+		{ "version",	0, 0, 'v' }, 
+		{ "file",	1, 0, 'f' },
+		{ "no-daemon",	0, 0, 'D' },
+		{ "manual",	0, 0, 'm' },
+		{ "verbosity",	1, 0, 'V' },
 		{ 0, 0, 0, 0 }, 
 	};
 	int ch,option_index = 0;
@@ -347,7 +347,7 @@ static int read_args (int argc, char *argv[]) {
  */
 static void print_version(const char *me) {
 	printf("%s version "__CPUFREQD_VERSION__".\n", me);
-	printf("Copyright 2002-2006 Mattia Dongili <"__CPUFREQD_MAINTAINER__">\n"
+	printf("Copyright 2002-2008 Mattia Dongili <"__CPUFREQD_MAINTAINER__">\n"
 	       "                    George Staikos <staikos@0wned.org>\n");
 }
 
@@ -363,7 +363,7 @@ static void print_help(const char *me) {
 			"  -m, --manual                 start in manual mode (ignored if the enable_remote is 0)\n"
 			"  -V, --verbosity              verbosity level from 0 (less verbose) to 7 (most verbose)\n"
 			"\n"
-			"Report bugs to Mattia Dongili <malattia@linux.it>.\n", me);
+			"Report bugs to Mattia Dongili <"__CPUFREQD_MAINTAINER__">.\n", me);
 }
 
 static void term_handler(int signo) {
@@ -839,6 +839,11 @@ cpufreqd_start:
 		sigaddset(&signal_action.sa_mask, SIGALRM);
 		sigprocmask(SIG_BLOCK, &signal_action.sa_mask, &old_sigmask);
 	}
+	/* otherwise if for any reason the control socket is closed
+	 * force cpufreqd_mode to dynamic and move on
+	 */
+	else
+		cpufreqd_info->cpufreqd_mode = MODE_DYNAMIC;
 	
 	set_cpufreqd_runmode(cpufreqd_info->cpufreqd_mode);
 	/*
